var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import i18next from "../../../utils/i18n";
import { LANGUAGE_CODE, LANGUAGE_MAP } from "../../../common/constants";
export class NylasDisableEmails {
    constructor() {
        this.selectedConfiguration = undefined;
        this.name = 'disable-emails';
        this.selectedLanguage = undefined;
        this.organizerLocale = this.selectedLanguage || 'en';
        this.disableEmails = false;
    }
    connectedCallback() {
        debug('nylas-disable-emails', 'connectedCallback');
    }
    disconnectedCallback() {
        debug('nylas-disable-emails', 'disconnectedCallback');
    }
    componentWillLoad() {
        debug('nylas-disable-emails', 'componentWillLoad');
        this.host.setAttribute('name', this.name);
    }
    componentDidLoad() {
        debug('nylas-disable-emails', 'componentDidLoad');
        const lang = this.selectedConfiguration?.scheduler?.email_template?.organizer_locale || this.selectedLanguage || 'en';
        this.organizerLocale = lang;
        const isGroupConfig = this.selectedConfiguration?.group_booking !== undefined;
        const disableEmails = isGroupConfig
            ? this.selectedConfiguration?.group_booking?.disable_emails
            : this.selectedConfiguration?.event_booking?.disable_emails;
        this.disableEmails = disableEmails || false;
        this.handleSettingValue(false);
    }
    elementNameChangedHandler(newValue) {
        debug('nylas-disable-emails', 'elementNameChangedHandler', newValue);
        this.host.setAttribute('name', newValue);
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
    }
    selectedConfigurationChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        this.organizerLocale = newVal.scheduler?.email_template?.organizer_locale || this.selectedLanguage || 'en';
        this.handleSettingValue(false);
        const isGroupConfig = newVal?.group_booking !== undefined;
        const disableEmails = isGroupConfig ? newVal?.group_booking?.disable_emails : newVal?.event_booking?.disable_emails;
        this.disableEmails = disableEmails || false;
        this.handleSettingValue(false);
    }
    nyalsFormSwitchToggledHandler(event) {
        debug('nylas-confirmation-email', 'nyalsFormSwitchToggledHandler', event.detail);
        const { checked } = event.detail;
        if (event.detail.name === 'disable-emails') {
            this.disableEmails = !checked;
            this.handleSettingValue();
        }
    }
    nylasFormDropdownChangedHandler(event) {
        const { name, value } = event.detail;
        if (name === 'organizer-locale') {
            const lang = LANGUAGE_CODE[value];
            this.organizerLocale = lang;
            this.handleSettingValue();
        }
    }
    handleSettingValue(valueChanged = true) {
        if (valueChanged) {
            this.valueChanged.emit({
                value: JSON.stringify({
                    disableEmails: this.disableEmails,
                    organizerLocale: this.organizerLocale,
                }),
                name: this.name,
            });
        }
        this.internals.setFormValue(JSON.stringify({
            disableEmails: this.disableEmails,
            organizerLocale: this.organizerLocale,
        }), this.name);
    }
    render() {
        const languageOptions = Object.keys(LANGUAGE_MAP).map(key => ({
            label: LANGUAGE_MAP[key],
            value: key,
        }));
        const isGroupConfig = this.selectedConfiguration?.group_booking !== undefined;
        const disableEmails = isGroupConfig
            ? this.selectedConfiguration?.group_booking?.disable_emails
            : this.selectedConfiguration?.event_booking?.disable_emails;
        return (h(Host, { key: '941088dd91a244983a80a04dbbbb46ab28f1a5ef' }, h("div", { key: 'd665ef6a8dcc447ae8f635ab272bd4d3a1112e33', class: "nylas-disable-emails", part: "nde" }, h("div", { key: 'e7a019347fdafcc16cc43418736c449a6a16c973', class: "header", part: "nde__header" }, h("div", { key: '0d76930e6c62ffb3dd90994d1f4c2268d453fd2e' }, h("h3", { key: 'feb3d9685de4d5f8afcc07f92009e081b45db3f5' }, i18next.t('eventCommunicationsTitle')), h("p", { key: 'd70821dd9fabfdd434b8996606eb59170ac68fa2' }, i18next.t('eventCommunicationsDescription')))), h("div", { key: '59dbfe7cbdc924d31491f171d37facb3e86647f5', class: "toggle", part: "nde__toggle" }, h("label", { key: '8c174626986502dfc8a289f42860fdba99dc3a34' }, i18next.t('nylasConfirmationEmail.confirmationEmail.label'), h("span", { key: 'd93d662d85acc0a471148414b853f13053b61d50', class: "label-icon" }, h("tooltip-component", { key: 'ad8cad66ad7563643c70824121d71d92e6a4317b' }, h("info-icon", { key: 'c5d799c845d62255ba3c3d440a3e6b84a51908b5', slot: "tooltip-icon" }), h("span", { key: 'dae8182eb6a44d8b41066293307ec9a24a87040a', slot: "tooltip-content" }, " ", i18next.t('nylasConfirmationEmail.confirmationEmail.tooltip.desc'))))), h("toggle-switch", { key: '7e224fdbdfdebe60cff8a637e9d711381ab19d06', exportparts: "ts_label: nde__toggle-label, ts_input: nde_toggle-input, ts_slider: nde_toggle-slider", name: `disable-emails`, checked: !disableEmails })), h("div", { key: 'a1fdb40b09ba165a389a4e114b0d4c29a7886099', class: "toggle", part: "nde__toggle" }, h("label", { key: 'a45f4775286f1a7b82015bfb6269d2f2e2f8be42' }, i18next.t('nylasConfirmationEmail.confirmationEmail.language'), h("span", { key: '7e41cafb4baa638883b06f314f4600b3eaf0d3c5', class: "label-icon" }, h("tooltip-component", { key: '0b2dde79fbed3fab9b3f3ff720f51d2a3bc5fd88' }, h("info-icon", { key: 'ec170eb55c4f36e7257458b5f81d769d243d14e9', slot: "tooltip-icon" }), h("span", { key: 'db4c80a7f579511e586581c2fb0b6f140f9c8a1e', slot: "tooltip-content" }, " ", i18next.t('nylasConfirmationEmail.confirmationEmail.tooltip.language'))))), h("select-dropdown", { key: '22cdc5868f66e8a535d7ea1bebad9924e1d41c2d', name: "organizer-locale", options: languageOptions, searchPlaceholder: i18next.t('search'), withChevron: false, defaultSelectedOption: languageOptions.find(lang => lang.value == this.organizerLocale), exportparts: "sd_dropdown: nse__language-dropdown, sd_dropdown-button: nse__language-drop-button, sd_dropdown-content: nse__language-drop-content, sd_dropdown_label: nse__language-drop-label" }, h("span", { key: '062ce2cbe185c55c055cdbb364f948414b89df08', slot: "select-icon" }, h("translate-icon", { key: 'ca645ba7d6f4f626131b329b14d99ea6bf05c6bc', width: "20", height: "20" })))))));
    }
    static get is() { return "nylas-disable-emails"; }
    static get encapsulation() { return "shadow"; }
    static get formAssociated() { return true; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-disable-emails.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-disable-emails.css"]
        };
    }
    static get properties() {
        return {
            "selectedConfiguration": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Configuration | GroupConfiguration",
                    "resolved": "Configuration | GroupConfiguration | undefined",
                    "references": {
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        },
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The selected config"
                        }],
                    "text": ""
                }
            },
            "name": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The name of the component"
                        }],
                    "text": ""
                },
                "attribute": "name",
                "reflect": false,
                "defaultValue": "'disable-emails'"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "organizerLocale": {},
            "disableEmails": {}
        };
    }
    static get events() {
        return [{
                "method": "valueChanged",
                "name": "valueChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is fired when the toggle switch to disable emails is toggled."
                },
                "complexType": {
                    "original": "{\n    value: string;\n    name: string;\n    valueChanged?: (event: CustomEvent<{ value: string; name: string }>) => void;\n  }",
                    "resolved": "{ value: string; name: string; valueChanged?: ((event: CustomEvent<{ value: string; name: string; }>) => void) | undefined; }",
                    "references": {
                        "CustomEvent": {
                            "location": "global",
                            "id": "global::CustomEvent"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "name",
                "methodName": "elementNameChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }, {
                "propName": "selectedConfiguration",
                "methodName": "selectedConfigurationChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "nylasFormSwitchToggled",
                "method": "nyalsFormSwitchToggledHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "nylasFormDropdownChanged",
                "method": "nylasFormDropdownChangedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
    static get attachInternalsMemberName() { return "internals"; }
}
__decorate([
    RegisterComponent({
        name: 'nylas-disable-emails',
        stateToProps: new Map([
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
            ['schedulerConfig.selectedConfiguration', 'selectedConfiguration'],
        ]),
        eventToProps: {
            valueChanged: async (event, _nylasSchedulerConfigConnector) => {
                const { valueChanged } = event.detail;
                if (valueChanged) {
                    valueChanged(event);
                }
            },
        },
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasDisableEmails.prototype, "render", null);
//# sourceMappingURL=nylas-disable-emails.js.map
