var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(k, v);
};
import { RegisterComponent } from "../../../common/register-component";
import { debug, mergeDeep, parsePreviewLink } from "../../../utils/utils";
import { Host, h } from "@stencil/core";
import TabContentsGroup, { TabGroup } from "./tab-contents-group";
import { CONFIGURATION_EVENT_TYPE, editorGroupTabComponentNames } from "../../../common/constants";
import * as Sentry from "@sentry/browser";
import i18next from "../../../utils/i18n";
export class NylasEditorTabsGroup {
    constructor() {
        this.formSubmissionHandler = async (event) => {
            event.preventDefault();
            const formEvent = await this.formSubmitted.emit();
            debug('[nylas-editor-tabs-group]', 'formSubmissionHandler', formEvent);
            const valid = this.formRef.checkValidity();
            if (!valid || formEvent.defaultPrevented) {
                this.error = this.formRef.validationMessage || 'Please fix the form errors.';
                return;
            }
            this.isLoading = true;
            this.hasUnsavedChanges = false;
            const formState = this.updateFormState();
            debug('[nylas-editor-tabs-group]', 'formState', formState);
            const { title, description, bookingCalendar, location, bookingType, minCancellationNotice, minBookingNotice, cancellationPolicy, hideCancellationOptions, hideReschedulingOptions, additionalFields, conferencing, reminders, emailTemplate, redirectUrl, slug, appearance, name, eventCapacity, eventTimeslot, participants, disableEmails, organizerLocale, } = formState;
            const configObject = {
                ...(this.selectedConfiguration?.id && { id: this.selectedConfiguration.id }),
                slug: slug,
                name: name,
                type: this.selectedEventType === CONFIGURATION_EVENT_TYPE.group ? CONFIGURATION_EVENT_TYPE.group : undefined,
                scheduler: {
                    cancellation_policy: cancellationPolicy ?? '',
                    min_cancellation_notice: minCancellationNotice ?? 0,
                    min_booking_notice: minBookingNotice ?? 60,
                    hide_cancellation_options: hideCancellationOptions ?? false,
                    hide_rescheduling_options: hideReschedulingOptions ?? false,
                    additional_fields: additionalFields,
                    email_template: emailTemplate
                        ? {
                            ...emailTemplate,
                            organizer_locale: organizerLocale || 'en',
                            logo: emailTemplate.logo || '',
                        }
                        : undefined,
                    confirmation_redirect_url: redirectUrl,
                },
                appearance: appearance,
                group_booking: {
                    booking_type: bookingType ? bookingType : 'booking',
                    disable_emails: typeof disableEmails === 'boolean' ? disableEmails : false,
                    reminders: reminders,
                    conferencing: conferencing,
                    calendar_id: bookingCalendar || 'primary',
                    default_capacity: eventCapacity || 10,
                },
            };
            const configObjectWithDeveloperSettings = mergeDeep(this.selectedConfiguration, configObject || {});
            const finalConfig = this.action === 'create' ? configObjectWithDeveloperSettings : configObject;
            delete finalConfig.availability;
            delete finalConfig.participants;
            delete finalConfig.event_booking;
            const resetLoadingState = (_e) => {
                this.isLoading = false;
                this.changesSaved = true;
                setTimeout(() => {
                    this.changesSaved = false;
                }, 3000);
            };
            const hasBookingError = this.checkForBookingFormErrors(finalConfig);
            if (hasBookingError) {
                return;
            }
            const organizer = {
                name: this.currentUser?.name ?? this.currentUser?.email ?? '',
                email: this.currentUser?.email ?? '',
            };
            const organizerDefaultCal = this.calendars?.find(c => c.is_primary) ?? this.calendars?.[0];
            const organizerParticipant = [{ ...organizer, is_organizer: true }];
            const groupEvent = !this.selectedConfiguration?.id
                ? {
                    title: title,
                    description: description,
                    location: !conferencing ? location : undefined,
                    conferencing: !location ? conferencing : undefined,
                    when: {
                        start_time: eventTimeslot?.when?.start_time ?? 0,
                        end_time: eventTimeslot?.when?.end_time ?? 0,
                        start_timezone: eventTimeslot?.when?.start_timezone ?? '',
                        end_timezone: eventTimeslot?.when?.end_timezone ?? '',
                    },
                    recurrence: eventTimeslot?.recurrence ?? [],
                    calendar_id: bookingCalendar || organizerDefaultCal?.id || 'primary',
                    participants: participants?.length ? participants : organizerParticipant,
                    organizer: organizer,
                    capacity: eventCapacity || 10,
                }
                : undefined;
            this.schedulerConfigChanged.emit({ groupEvent: groupEvent || undefined, config: finalConfig, resetLoadingState: resetLoadingState, action: this.action, host: this.host });
        };
        this.checkForBookingFormErrors = config => {
            let hasError = false;
            let errorMessage = '';
            const additionalFields = config.scheduler?.additional_fields;
            if (additionalFields) {
                errorMessage = i18next.t('nylasEditorTabs.bookingFormError');
                Object.entries(additionalFields).forEach(entry => {
                    const field = entry[1];
                    if (field.label === '') {
                        errorMessage += i18next.t('nylasEditorTabs.bookingFormError_label', { type: field.type });
                        hasError = true;
                        return;
                    }
                    if (field.options) {
                        for (const option of field.options) {
                            if (option.trim() === '') {
                                errorMessage += i18next.t('nylasEditorTabs.bookingFormError_option', { label: field.label, type: field.type });
                                hasError = true;
                                break;
                            }
                        }
                    }
                });
            }
            if (hasError) {
                this.isLoading = false;
                this.host.setError(new Error(errorMessage));
            }
            return hasError;
        };
        this.calendars = undefined;
        this.selectedConfiguration = undefined;
        this.configurations = undefined;
        this.currentUser = undefined;
        this.schedulerPreviewLink = '';
        this.mode = 'app';
        this.hideEditorTabs = [];
        this.enableUserFeedback = true;
        this.selectedLanguage = undefined;
        this.selectedEventType = undefined;
        this.selectedGroupEvent = undefined;
        this.action = 'create';
        this.showFeedbackModal = false;
        this.activeTab = TabGroup.CalendarView;
        this.isLoading = false;
        this.hasUnsavedChanges = false;
        this.changesSaved = false;
        this.formState = {};
        this.error = '';
    }
    configChangedHandler(newConfig) {
        debug('[nylas-editor-tabs-group]', 'configChangedHandler', newConfig, this.selectedConfiguration);
        this.formState = {
            ...this.getFormStateFromConfig(newConfig),
        };
        if (newConfig?.id) {
            this.action = 'edit';
        }
        else {
            this.action = 'create';
        }
    }
    selectedGroupEventChangedHandler(newConfig) {
        debug('[nylas-editor-tabs-group]', 'selectedGroupEventChangedHandler', newConfig, this.selectedConfiguration);
        this.formState = {
            ...this.formState,
            title: this.selectedGroupEvent?.event?.title,
            description: this.selectedGroupEvent?.event?.description,
            location: this.selectedGroupEvent?.event?.location,
            conferencing: this.selectedGroupEvent?.event?.conferencing,
            eventCapacity: this.selectedGroupEvent?.group_event_info?.capacity,
            participants: this.selectedGroupEvent?.group_event_info?.participants?.map(participant => ({
                name: participant.name,
                email: participant.email,
                is_organizer: !!participant.is_organizer,
            })),
            eventTimeslot: this.selectedGroupEvent?.event?.when
                ? {
                    when: {
                        start_time: this.selectedGroupEvent?.event?.when?.start_time,
                        end_time: this.selectedGroupEvent?.event?.when?.end_time,
                        start_timezone: this.selectedGroupEvent?.event?.when?.start_timezone,
                        end_timezone: this.selectedGroupEvent?.event?.when?.end_timezone,
                    },
                    recurrence: this.selectedGroupEvent?.group_event_info?.rrule ? this.selectedGroupEvent?.group_event_info?.rrule : [],
                }
                : undefined,
        };
    }
    userChangedHandler(newUser) {
        debug('[nylas-editor-tabs-group]', 'userChangedHandler', newUser);
        if (newUser) {
            this.formState = {
                ...this.getFormStateFromConfig(this.selectedConfiguration),
            };
        }
    }
    selectedLanguageChangedHandler(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        i18next.changeLanguage(newVal);
    }
    async schedulerConfigCreatedEventHandler(data) {
        const event = this.schedulerConfigCreated.emit(data);
        return event;
    }
    async setError(error) {
        this.error = error.message;
    }
    async resetError() {
        this.error = '';
    }
    connectedCallback() {
        debug('[nylas-editor-tabs-group]', 'connectedCallback');
    }
    componentWillLoad() {
        debug('[nylas-editor-tabs-group]', 'componentWillLoad');
        this.formState = this.getFormStateFromConfig(this.selectedConfiguration);
    }
    componentDidLoad() {
        debug('[nylas-editor-tabs-group]', 'componentDidLoad');
        if (this.enableUserFeedback && !Sentry.isInitialized()) {
            Sentry.init({
                dsn: 'https://9d5731f1c77ca84c9ed3fb9b3ccf7ee1@o74852.ingest.us.sentry.io/4507889638178816',
                release: process.env.PACKAGE_VERSION,
                integrations: integrations => [
                    ...integrations.filter(_integration => false),
                    Sentry.feedbackIntegration({
                        colorScheme: 'system',
                        autoInject: false,
                    }),
                ],
                autoSessionTracking: false,
                beforeSend: () => null,
            });
        }
        if (this.selectedConfiguration?.id) {
            this.configChangedHandler(this.selectedConfiguration);
        }
        const firstVisibleTab = this.host.querySelector('button.tab:not(.hide)')?.name;
        if (firstVisibleTab && this.hideEditorTabs?.includes(this.activeTab)) {
            this.activeTab = firstVisibleTab;
        }
        this.updateFormState();
    }
    disconnectedCallback() {
        debug('[nylas-editor-tabs-group]', 'disconnectedCallback');
    }
    handleValueChanged(event) {
        debug('[nylas-editor-tabs-group]', 'handleValueChanged', event);
        const { name, value } = event.detail;
        console.log('name', name, 'value', value);
        this.setFormState(value, name);
        this.formState = { ...this.formState };
        if (editorGroupTabComponentNames.includes(name)) {
            this.hasUnsavedChanges = true;
        }
        this.error = '';
        this.schedulerEditorFormUpdated.emit({
            value: event.detail.value,
            name: event.detail.name,
        });
    }
    feedbackModalClosedHandler() {
        this.showFeedbackModal = false;
    }
    feedbackSubmittedHandler(event) {
        const eventId = Sentry.captureMessage('Scheduler Editor User Feedback');
        const feedback = {
            eventId: eventId,
            message: event.detail.feedback,
        };
        Sentry.captureFeedback(feedback, {
            includeReplay: true,
            captureContext: {
                tags: {
                    'nylas-web-element': 'nylas-scheduler-editor',
                    'nylas-web-element-version': process.env.PACKAGE_VERSION,
                },
                extra: {
                    configId: this.selectedConfiguration?.id,
                    slug: this.selectedConfiguration?.slug,
                },
            },
        });
        this.showFeedbackModal = false;
    }
    importGroupEventHandler(event) {
        this.groupEventImportTriggered.emit({ groupEvent: event.detail, configId: this.selectedConfiguration?.id ?? '', host: this.host });
    }
    saveGroupEventChangesHandler(event) {
        debug('saveGroupEventChangesHandler', event.detail, this.selectedGroupEvent);
        const valid = this.formRef.checkValidity();
        const groupEvent = this.getGroupEventDetailsFromFormState();
        this.resetError();
        if (!groupEvent.title) {
            this.setError(new Error('Event title is required.'));
        }
        if (!groupEvent.when?.start_time || !groupEvent.when?.end_time) {
            this.setError(new Error('Event time is required.'));
        }
        if (!groupEvent.participants?.length) {
            this.setError(new Error('Participants are required.'));
        }
        if (groupEvent.participants?.length && groupEvent.participants?.some(p => !p.email)) {
            this.setError(new Error('Participant email is required.'));
        }
        if (this.error !== '' || !valid) {
            this.saveGroupEventChangesError.emit({
                error: this.error ?? 'An error occurred while saving changes.',
                configId: this.selectedConfiguration?.id ?? '',
                host: this.host,
            });
            return;
        }
        this.groupEventUpdateTriggered.emit({
            groupEvent: groupEvent,
            chosenOption: event.detail.action,
            configId: this.selectedConfiguration?.id ?? '',
            host: this.host,
        });
    }
    deleteGroupEventHandler(event) {
        debug('deleteGroupEventHandler', event.detail);
        const groupEvent = this.getGroupEventDetailsFromFormState();
        this.groupEventDeleteTriggered.emit({
            groupEvent: groupEvent,
            chosenOption: event.detail.action,
            configId: this.selectedConfiguration?.id ?? '',
            host: this.host,
        });
    }
    createGroupEventHandler(event) {
        const formState = event.detail;
        const organizer = {
            name: this.currentUser?.name ?? this.currentUser?.email ?? '',
            email: this.currentUser?.email ?? '',
        };
        const organizerDefaultCal = this.calendars?.find(c => c.is_primary) ?? this.calendars?.[0];
        const conferencing = this.formState?.conferencing || formState.conferencing;
        const groupEvent = {
            title: formState.title,
            description: formState.description,
            location: !conferencing ? formState.location : undefined,
            participants: formState.participants,
            organizer: organizer,
            conferencing: !formState.location ? conferencing : {},
            when: formState.eventTimeslot.when,
            recurrence: formState.eventTimeslot.recurrence,
            calendar_id: organizerDefaultCal?.id || 'primary',
            capacity: formState.eventCapacity,
        };
        this.groupEventCreateTriggered.emit({ groupEvent, configId: this.selectedConfiguration?.id ?? '', host: this.host });
    }
    getGroupEventDetailsFromFormState() {
        const organizerDefaultCal = this.calendars?.find(c => c.is_primary) ?? this.calendars?.[0];
        const organizer = {
            name: this.currentUser?.name ?? this.currentUser?.email ?? '',
            email: this.currentUser?.email ?? '',
        };
        const participantOrganizer = [{ ...organizer, is_organizer: true }];
        const { title, description, bookingCalendar, location, conferencing, eventCapacity, eventTimeslot, participants } = this.formState;
        return {
            title: title,
            description: description,
            location: !conferencing ? location : undefined,
            conferencing: !location ? conferencing : undefined,
            when: {
                start_time: eventTimeslot?.when?.start_time ?? 0,
                end_time: eventTimeslot?.when?.end_time ?? 0,
                start_timezone: eventTimeslot?.when?.start_timezone ?? '',
                end_timezone: eventTimeslot?.when?.end_timezone ?? '',
            },
            recurrence: eventTimeslot?.recurrence ?? [],
            calendar_id: bookingCalendar || organizerDefaultCal?.id || 'primary',
            participants: participants?.length ? participants : participantOrganizer,
            organizer: organizer,
            capacity: eventCapacity || 10,
        };
    }
    getFormStateFromConfig(config) {
        if (config?.appearance) {
            console.info('Appearance settings have been returned from the given configuration; please remember to grab them from the configSettingsLoaded event and apply them as desired.');
        }
        return {
            additionalFields: config?.scheduler?.additional_fields ?? {},
            bookingType: config?.group_booking?.booking_type ?? 'booking',
            cancellationPolicy: config?.scheduler?.cancellation_policy ?? '',
            minCancellationNotice: config?.scheduler?.min_cancellation_notice ?? 0,
            minBookingNotice: config?.scheduler?.min_booking_notice ?? 60,
            hideCancellationOptions: config?.scheduler?.hide_cancellation_options ?? false,
            hideReschedulingOptions: config?.scheduler?.hide_rescheduling_options ?? false,
            reminders: config?.group_booking?.reminders,
            emailTemplate: config?.scheduler?.email_template,
            redirectUrl: config?.scheduler?.confirmation_redirect_url,
            slug: config?.slug,
            appearance: config?.appearance,
            name: config?.name,
            bookingCalendar: config?.group_booking?.calendar_id,
            disableEmails: config?.group_booking?.disable_emails,
            organizerLocale: config?.scheduler?.email_template?.organizer_locale,
        };
    }
    setFormState(value, key) {
        switch (key) {
            case 'title':
                this.formState.title = value.toString();
                break;
            case 'description':
                this.formState.description = value.toString();
                break;
            case 'location':
                this.formState.location = value.toString();
                break;
            case 'conference':
                this.formState.conferencing = JSON.parse(value.toString());
                break;
            case 'confirmation-type':
                this.formState.bookingType = value.toString();
                break;
            case 'min-cancellation-notice':
                this.formState.minCancellationNotice = parseInt(value.toString());
                break;
            case 'min-booking-notice':
                this.formState.minBookingNotice = parseInt(value.toString());
                break;
            case 'cancellation-policy':
                this.formState.cancellationPolicy = value.toString();
                break;
            case 'customize-booking-settings': {
                const settings = JSON.parse(value.toString());
                this.formState.hideCancellationOptions = settings.hideCancellationOptions;
                this.formState.hideReschedulingOptions = settings.hideReschedulingOptions;
                break;
            }
            case 'booking-calendar':
                this.formState.bookingCalendar = value.toString();
                break;
            case 'event-capacity':
                this.formState.eventCapacity = parseInt(String(value));
                break;
            case 'additional-fields':
                this.formState.additionalFields = JSON.parse(value.toString());
                break;
            case 'confirmation-email-template':
                this.formState.emailTemplate = JSON.parse(value.toString());
                break;
            case 'reminder-overrides':
                this.formState.reminders = JSON.parse(value.toString());
                break;
            case 'confirmation-redirect':
                this.formState.redirectUrl = value.toString();
                break;
            case 'custom-event-slug':
                console.debug('custom-event-slug', value);
                this.formState.slug = JSON.parse(value.toString());
                break;
            case 'page-styling':
                this.formState.appearance = JSON.parse(value.toString());
                break;
            case 'page-name':
                this.formState.name = JSON.parse(value.toString());
                break;
            case 'participants': {
                const participants = JSON.parse(value.toString());
                this.formState.participants = participants.map(participant => ({
                    name: participant.name,
                    email: participant.email,
                    is_organizer: participant.is_organizer,
                }));
                break;
            }
            case 'event-timeslot':
                this.formState.eventTimeslot = JSON.parse(value.toString());
                break;
            case 'disable-emails': {
                const { disableEmails, organizerLocale } = JSON.parse(value.toString());
                this.formState.disableEmails = disableEmails;
                this.formState.organizerLocale = organizerLocale;
                break;
            }
        }
        this.schedulerEditorFormUpdated.emit({
            value,
            name: key,
        });
    }
    updateFormState() {
        const formData = new FormData(this.formRef);
        formData.forEach((value, key) => {
            this.setFormState(value, key);
        });
        this.formState = { ...this.formState };
        return this.formState;
    }
    setActiveTab(e, tabName) {
        e.preventDefault();
        this.updateFormState();
        this.activeTab = tabName;
    }
    hideTab(tab) {
        return this.hideEditorTabs?.includes(tab) || false;
    }
    onFeedbackClick(e) {
        e.preventDefault();
        this.showFeedbackModal = true;
    }
    render() {
        debug('[nylas-editor-tabs-group]', 'render', this.formState);
        return (h(Host, { key: '2f1b119172917fda91ffa866f37a14355f2828c0' }, h("form", { key: '103788b60f9351f7b20bcb06e1e93f89a29a9332', onSubmit: this.formSubmissionHandler, class: "scheduler-editor", ref: el => (this.formRef = el), noValidate: true }, this.mode === 'app' ? (h("div", { class: "return-to-calendar-view", part: "editor__return-to-calendar-view net__return-to-calendar-view" }, h("button-component", { id: "return-to-calendar-view-button", variant: "invisible", part: "nset__header__back-button", type: "button", onClick: e => {
                this.setActiveTab(e, TabGroup.CalendarView);
            } }, h("chevron-icon", { width: "16", height: "16" }), h("span", null, i18next.t('returnToCalendarView'))))) : null, this.mode === 'app' ? (h("div", { class: "form-contents", part: "editor__form-contents net__form-contents" }, h("div", { class: "tabs", part: "editor__tabs net__tabs" }, h("button", { name: TabGroup.BookingOptions, class: { tab: true, active: this.activeTab == TabGroup.BookingOptions, hide: this.hideTab(TabGroup.BookingOptions) }, part: "editortab__booking-options net__tab-booking-options", onClick: e => this.setActiveTab(e, TabGroup.BookingOptions) }, h("flow-icon", { width: "16", height: "16" }), i18next.t('bookingOptionsTab')), h("button", { name: TabGroup.BookingForm, class: { tab: true, active: this.activeTab == TabGroup.BookingForm, hide: this.hideTab(TabGroup.BookingForm) }, part: "editortab__booking-form net__tab-booking-form", onClick: e => this.setActiveTab(e, TabGroup.BookingForm) }, this.activeTab == TabGroup.BookingForm ? h("calendar-agenda-fill-icon", { width: "16", height: "16" }) : h("calendar-agenda-icon", { width: "16", height: "16" }), i18next.t('bookingFormTab')), h("button", { name: TabGroup.Communications, class: { tab: true, active: this.activeTab == TabGroup.Communications, hide: this.hideTab(TabGroup.Communications) }, onClick: e => this.setActiveTab(e, TabGroup.Communications), part: "editortab__communications net__tab-communications" }, this.activeTab == TabGroup.Communications ? h("envelope-fill-icon", { width: "16", height: "16" }) : h("envelope-icon", { width: "16", height: "16" }), i18next.t('communicationsTab')), h("button", { name: TabGroup.PageStyles, class: { tab: true, active: this.activeTab == TabGroup.PageStyles, hide: this.hideTab(TabGroup.PageStyles) }, onClick: e => this.setActiveTab(e, TabGroup.PageStyles), part: "editortab__page-styles net__tab-page-styles" }, this.activeTab == TabGroup.PageStyles ? h("paintbrush-fill-icon", { width: "16", height: "16" }) : h("paintbrush-icon", { width: "16", height: "16" }), i18next.t('pageStylesTab'))), h("div", { class: "tab-content", part: "editor__tab-content net__tab-content" }, h(TabContentsGroup, { formState: this.formState, activeTab: this.activeTab, currentUser: this.currentUser, calendars: this.calendars, id: this.selectedConfiguration?.id ?? 'new', i18next: i18next })))) : (h("div", { class: "composable", key: this.selectedConfiguration?.id }, h("slot", null))), h("div", { key: '5c98656ec4f4b3bb61f675dbfe43121b1cf230cf', class: "footer", part: "editor__footer net__footer" }, h("div", { key: 'cca7ec210ba25fd6e8d6f090871bd03acd86f3b2', class: "preview", part: "editor__footer-preview net__footer-preview" }, this.enableUserFeedback && (h("button-component", { title: "Share your feedback", id: "report-issue", variant: 'basic', onClick: e => this.onFeedbackClick(e) }, h("feedback-icon", null))), this.activeTab === TabGroup.CalendarView && (h("button-component", { title: "Go to page settings", id: "page-settings", variant: 'basic', onClick: e => this.setActiveTab(e, TabGroup.BookingOptions) }, i18next.t('pageSettingsButton')))), h("div", { key: '53bf5ccc9597574dade9a81c08a4b316ebbb8f1e', class: "buttons", part: "editor__footer-buttons net__footer-buttons" }, h("p", { key: 'a3acb4bbfb391483d9d8914ff5f07922c05e7dbd', class: {
                'unsaved-changes': this.hasUnsavedChanges && !this.changesSaved,
                'saved-changes': this.changesSaved,
                'error': this.error !== '',
                'error-full-width': this.error !== '' && this.action === 'create',
            } }, this.error !== '' ? this.error : '', this.error == '' && this.hasUnsavedChanges && !this.changesSaved && this.activeTab !== TabGroup.CalendarView
            ? i18next.t('unsavedChangesLabel')
            : this.error == '' && this.changesSaved
                ? `${i18next.t('changesSavedLabel')}!`
                : ''), h("div", { key: '81e083f0560967f3d8b68f1e0cafef645c7ae288', class: "footer-buttons__row" }, this.schedulerPreviewLink !== '' && this.action === 'edit' && (h("button-component", { title: "Preview", type: "button", disabled: this.isLoading, clickHandler: event => {
                event.preventDefault();
                const previewEvent = this.previewButtonClicked.emit(this.host);
                if (!previewEvent.defaultPrevented) {
                    window.open(parsePreviewLink(this.schedulerPreviewLink, this.selectedConfiguration), '_blank');
                }
            }, variant: 'basic' }, h("eye-icon", null))), h("button-component", { key: '59a4f7e7238f88a4a07e0bc1ab79bed788da74c9', type: "button", disabled: this.isLoading, clickHandler: event => {
                event.preventDefault();
                this.cancelButtonClick.emit();
                this.error = '';
            }, variant: 'basic', part: "editor__footer-cancel net__footer-cancel" }, i18next.t('backButton')), h("button-component", { key: '3ed3bc81b39988173e13f2c3346defed31b96148', type: "submit", disabled: this.isLoading, part: "editor__footer-cta, net__footer-cta" }, this.isLoading ? (h("span", null, i18next.t('savingButtonText'), h("loading-icon", null), ' ')) : this.action === 'create' ? (`${i18next.t('createButtonText')}`) : (`${i18next.t('saveChangesButtonText')}`)))))), this.showFeedbackModal && h("nylas-feedback-form", null)));
    }
    static get is() { return "nylas-editor-tabs-group"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["nylas-editor-tabs-group.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nylas-editor-tabs-group.css"]
        };
    }
    static get properties() {
        return {
            "calendars": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Calendar[]",
                    "resolved": "Calendar[] | undefined",
                    "references": {
                        "Calendar": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Calendar"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The list of calendars to use in the editor when configuring availability."
                        }],
                    "text": ""
                }
            },
            "selectedConfiguration": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "GroupConfiguration",
                    "resolved": "GroupConfiguration | undefined",
                    "references": {
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The selected configuration to use in the editor when editing an existing configuration or creating a new one."
                        }],
                    "text": ""
                }
            },
            "configurations": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(Configuration | GroupConfiguration)[]",
                    "resolved": "(Configuration | GroupConfiguration)[] | undefined",
                    "references": {
                        "Configuration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::Configuration"
                        },
                        "GroupConfiguration": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupConfiguration"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The list of configurations"
                        }],
                    "text": ""
                }
            },
            "currentUser": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "User",
                    "resolved": "undefined | { id: string; email: string; name?: string | undefined; provider?: string | undefined; }",
                    "references": {
                        "User": {
                            "location": "import",
                            "path": "@/common/nylas-api-request",
                            "id": "src/common/nylas-api-request.ts::User"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The current logged in user."
                        }],
                    "text": ""
                }
            },
            "schedulerPreviewLink": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The scheduler preview link to use when the user clicks on the preview button.\nYou can use a placeholder `{config.id}` to replace the configuration id anywhere in the link."
                        }],
                    "text": ""
                },
                "attribute": "scheduler-preview-link",
                "reflect": false,
                "defaultValue": "''"
            },
            "mode": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'app' | 'composable'",
                    "resolved": "\"app\" | \"composable\" | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "The mode of the editor.\n- `app`: The editor is used as a standalone app.\n- `composable`: The editor is used as a composable component."
                        }],
                    "text": ""
                },
                "attribute": "mode",
                "reflect": false,
                "defaultValue": "'app'"
            },
            "hideEditorTabs": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "TabGroup[]",
                    "resolved": "TabGroup[] | undefined",
                    "references": {
                        "TabGroup": {
                            "location": "import",
                            "path": "./tab-contents-group",
                            "id": "src/components/scheduler-editor/nylas-editor-tabs-group/tab-contents-group.tsx::TabGroup"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "This prop is passed down by the parent component.\nIt is an optional prop is used to hide tabs in the editor. Available tabs are:\neventInfo, availability, participants, bookingOptions, bookingForm"
                        }],
                    "text": ""
                },
                "defaultValue": "[]"
            },
            "enableUserFeedback": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "standalone",
                            "text": "This prop is passed down by the parent component to enable or disable user feedback."
                        }],
                    "text": ""
                },
                "attribute": "enable-user-feedback",
                "reflect": false,
                "defaultValue": "true"
            },
            "selectedLanguage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "LANGUAGE_CODE",
                    "resolved": "LANGUAGE_CODE.de | LANGUAGE_CODE.en | LANGUAGE_CODE.es | LANGUAGE_CODE.fr | LANGUAGE_CODE.ja | LANGUAGE_CODE.ko | LANGUAGE_CODE.nl | LANGUAGE_CODE.sv | LANGUAGE_CODE.zh | undefined",
                    "references": {
                        "LANGUAGE_CODE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::LANGUAGE_CODE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected language."
                },
                "attribute": "selected-language",
                "reflect": false
            },
            "selectedEventType": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "CONFIGURATION_EVENT_TYPE",
                    "resolved": "CONFIGURATION_EVENT_TYPE.collective | CONFIGURATION_EVENT_TYPE.group | CONFIGURATION_EVENT_TYPE.max_availability | CONFIGURATION_EVENT_TYPE.max_fairness | CONFIGURATION_EVENT_TYPE.one_on_one | undefined",
                    "references": {
                        "CONFIGURATION_EVENT_TYPE": {
                            "location": "import",
                            "path": "@/common/constants",
                            "id": "src/common/constants.ts::CONFIGURATION_EVENT_TYPE"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected event type."
                },
                "attribute": "selected-event-type",
                "reflect": false
            },
            "selectedGroupEvent": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "GroupEventAPIData",
                    "resolved": "GroupEventAPIData | undefined",
                    "references": {
                        "GroupEventAPIData": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEventAPIData"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The selected group event."
                }
            }
        };
    }
    static get states() {
        return {
            "action": {},
            "showFeedbackModal": {},
            "activeTab": {},
            "isLoading": {},
            "hasUnsavedChanges": {},
            "changesSaved": {},
            "formState": {},
            "error": {}
        };
    }
    static get events() {
        return [{
                "method": "schedulerConfigChanged",
                "name": "schedulerConfigChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the configuration is created/updated (after the request is complete). This fires for both create and edit actions."
                },
                "complexType": {
                    "original": "SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement }",
                    "resolved": "SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement; }",
                    "references": {
                        "SchedulerGroupEventDetail": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::SchedulerGroupEventDetail"
                        },
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }, {
                "method": "schedulerConfigCreated",
                "name": "schedulerConfigCreated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the configuration is created (after the request is made). This fires for only for create action."
                },
                "complexType": {
                    "original": "SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement }",
                    "resolved": "SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement; }",
                    "references": {
                        "SchedulerGroupEventDetail": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::SchedulerGroupEventDetail"
                        },
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }, {
                "method": "cancelButtonClick",
                "name": "cancelButtonClick",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the cancel button."
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }, {
                "method": "formSubmitted",
                "name": "formSubmitted",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted on form submission."
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }, {
                "method": "previewButtonClicked",
                "name": "previewButtonClicked",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the preview button."
                },
                "complexType": {
                    "original": "HTMLNylasEditorTabsGroupElement",
                    "resolved": "HTMLNylasEditorTabsGroupElement",
                    "references": {
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }, {
                "method": "schedulerEditorFormUpdated",
                "name": "schedulerEditorFormUpdated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "\nEvent emitted when the value of a form field changes."
                },
                "complexType": {
                    "original": "{ value: string; name: string }",
                    "resolved": "{ value: string; name: string; }",
                    "references": {}
                }
            }, {
                "method": "groupEventCreateTriggered",
                "name": "groupEventCreateTriggered",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the create button to create a new group event in the calendar view of the scheduler editor."
                },
                "complexType": {
                    "original": "{ groupEvent: Partial<GroupEvent>; configId: string; host: HTMLNylasEditorTabsGroupElement }",
                    "resolved": "{ groupEvent: Partial<GroupEvent>; configId: string; host: HTMLNylasEditorTabsGroupElement; }",
                    "references": {
                        "Partial": {
                            "location": "global",
                            "id": "global::Partial"
                        },
                        "GroupEvent": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEvent"
                        },
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }, {
                "method": "groupEventUpdateTriggered",
                "name": "groupEventUpdateTriggered",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "\nEvent emitted when the user clicks the save button to save the changes made to the group event in the calendar view of the scheduler editor."
                },
                "complexType": {
                    "original": "{\n    groupEvent: GroupEvent;\n    chosenOption: RecurrenceUpdateOption;\n    configId: string;\n    host: HTMLNylasEditorTabsGroupElement;\n  }",
                    "resolved": "{ groupEvent: GroupEvent; chosenOption: RecurrenceUpdateOption; configId: string; host: HTMLNylasEditorTabsGroupElement; }",
                    "references": {
                        "GroupEvent": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEvent"
                        },
                        "RecurrenceUpdateOption": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::RecurrenceUpdateOption"
                        },
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }, {
                "method": "groupEventDeleteTriggered",
                "name": "groupEventDeleteTriggered",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the delete button to delete the group event in the calendar view of the scheduler editor."
                },
                "complexType": {
                    "original": "{\n    groupEvent: GroupEvent;\n    chosenOption: RecurrenceDeleteOption;\n    configId: string;\n    host: HTMLNylasEditorTabsGroupElement;\n  }",
                    "resolved": "{ groupEvent: GroupEvent; chosenOption: RecurrenceDeleteOption; configId: string; host: HTMLNylasEditorTabsGroupElement; }",
                    "references": {
                        "GroupEvent": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::GroupEvent"
                        },
                        "RecurrenceDeleteOption": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::RecurrenceDeleteOption"
                        },
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }, {
                "method": "groupEventImportTriggered",
                "name": "groupEventImportTriggered",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "Event emitted when the user clicks the import button to import a group event in the calendar view of the scheduler editor."
                },
                "complexType": {
                    "original": "{\n    groupEvent: ImportGroupEventDetails;\n    configId: string;\n    host: HTMLNylasEditorTabsGroupElement;\n  }",
                    "resolved": "{ groupEvent: ImportGroupEventDetails; configId: string; host: HTMLNylasEditorTabsGroupElement; }",
                    "references": {
                        "ImportGroupEventDetails": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::ImportGroupEventDetails"
                        },
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }, {
                "method": "saveGroupEventChangesError",
                "name": "saveGroupEventChangesError",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": "This event is emitted when there is an error is saving changes to the group event in the calendar view of the scheduler editor."
                },
                "complexType": {
                    "original": "{\n    error: string;\n    configId: string;\n    host: HTMLNylasEditorTabsGroupElement;\n  }",
                    "resolved": "{ error: string; configId: string; host: HTMLNylasEditorTabsGroupElement; }",
                    "references": {
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    }
                }
            }];
    }
    static get methods() {
        return {
            "schedulerConfigCreatedEventHandler": {
                "complexType": {
                    "signature": "(data: SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement; }) => Promise<CustomEvent<SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement; }>>",
                    "parameters": [{
                            "name": "data",
                            "type": "SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "CustomEvent": {
                            "location": "global",
                            "id": "global::CustomEvent"
                        },
                        "SchedulerGroupEventDetail": {
                            "location": "import",
                            "path": "@nylas/core",
                            "id": "../nylas-js-core/dist/index.d.ts::SchedulerGroupEventDetail"
                        },
                        "HTMLNylasEditorTabsGroupElement": {
                            "location": "global",
                            "id": "global::HTMLNylasEditorTabsGroupElement"
                        }
                    },
                    "return": "Promise<CustomEvent<SchedulerGroupEventDetail & { host: HTMLNylasEditorTabsGroupElement; }>>"
                },
                "docs": {
                    "text": "Event handler for the scheduler config created event.",
                    "tags": []
                }
            },
            "setError": {
                "complexType": {
                    "signature": "(error: Error) => Promise<void>",
                    "parameters": [{
                            "name": "error",
                            "type": "Error",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "Error": {
                            "location": "global",
                            "id": "global::Error"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "Sets the error state of the editor.",
                    "tags": []
                }
            },
            "resetError": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "Resets the error state of the editor.",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "selectedConfiguration",
                "methodName": "configChangedHandler"
            }, {
                "propName": "selectedGroupEvent",
                "methodName": "selectedGroupEventChangedHandler"
            }, {
                "propName": "currentUser",
                "methodName": "userChangedHandler"
            }, {
                "propName": "selectedLanguage",
                "methodName": "selectedLanguageChangedHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "valueChanged",
                "method": "handleValueChanged",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "feedbackModalClosed",
                "method": "feedbackModalClosedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "feedbackSubmitted",
                "method": "feedbackSubmittedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "importGroupEvent",
                "method": "importGroupEventHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "saveGroupEventChanges",
                "method": "saveGroupEventChangesHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "deleteGroupEvent",
                "method": "deleteGroupEventHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "createGroupEvent",
                "method": "createGroupEventHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
__decorate([
    RegisterComponent({
        name: 'nylas-editor-tabs-group',
        stateToProps: new Map([
            ['schedulerConfig.calendars', 'calendars'],
            ['schedulerConfig.selectedConfiguration', 'selectedConfiguration'],
            ['schedulerConfig.currentUser', 'currentUser'],
            ['schedulerConfig.configurations', 'configurations'],
            ['schedulerConfig.selectedLanguage', 'selectedLanguage'],
            ['schedulerConfig.selectedEventType', 'selectedEventType'],
            ['schedulerConfig.selectedGroupEvent', 'selectedGroupEvent'],
        ]),
        eventToProps: {
            schedulerConfigChanged: async (event, nylasSchedulerConfigConnector) => {
                const { resetLoadingState, host, action, config, groupEvent } = event.detail;
                const checkForErrors = (response) => {
                    const [data, error] = response;
                    if (!data && error) {
                        host.setError(error);
                    }
                    else if (data && !error && action === 'create') {
                        host.schedulerConfigCreatedEventHandler({ config: data, action, host });
                    }
                };
                if (action === 'edit') {
                    const response = await nylasSchedulerConfigConnector.schedulerConfig.updateConfiguration(config);
                    checkForErrors(response);
                    if (resetLoadingState) {
                        resetLoadingState(event);
                    }
                }
                else {
                    const response = await nylasSchedulerConfigConnector.schedulerConfig.createConfiguration(config);
                    checkForErrors(response);
                    const [data, _error] = response;
                    const configId = data?.id;
                    if (configId && groupEvent) {
                        const eventResponse = await nylasSchedulerConfigConnector.schedulerConfig.createGroupEvent(groupEvent, configId);
                        checkForErrors(eventResponse);
                    }
                    if (resetLoadingState) {
                        resetLoadingState(event);
                    }
                }
            },
            cancelButtonClick: async (_, nylasSchedulerConfigConnector) => {
                nylasSchedulerConfigConnector.schedulerConfigStore.state.action = null;
                nylasSchedulerConfigConnector.schedulerConfigStore.set('selectedEventType', undefined);
                nylasSchedulerConfigConnector.schedulerConfigStore.set('selectedGroupEvent', undefined);
                nylasSchedulerConfigConnector.schedulerConfigStore.set('groupEvents', []);
            },
            previewButtonClicked: async (_, nylasSchedulerConfigConnector) => {
                debug('[nylas-editor-tabs-group]', 'previewButtonClicked', nylasSchedulerConfigConnector);
            },
            formSubmitted: async (_, nylasSchedulerConfigConnector) => {
                debug('[nylas-editor-tabs-group]', 'formSubmitted', nylasSchedulerConfigConnector);
            },
            schedulerEditorFormUpdated: async (event, _nylasSchedulerConfigConnector) => {
                debug('[nylas-editor-tabs-group]', 'schedulerEditorFormUpdated', event);
            },
            schedulerConfigCreated: async (event, _nylasSchedulerConfigConnector) => {
                debug('[nylas-editor-tabs-group]', 'schedulerConfigCreated', event);
            },
            groupEventUpdateTriggered: async (event, nylasSchedulerConfigConnector) => {
                const { groupEvent, host, chosenOption, configId } = event.detail;
                const response = await nylasSchedulerConfigConnector.schedulerConfig.updateGroupEvent(groupEvent, chosenOption, configId);
                const [data, error] = response;
                if (!data && error) {
                    host.setError(error);
                }
            },
            groupEventDeleteTriggered: async (event, nylasSchedulerConfigConnector) => {
                const { groupEvent, chosenOption, configId, host } = event.detail;
                const response = await nylasSchedulerConfigConnector.schedulerConfig.deleteGroupEvent(groupEvent, chosenOption, configId);
                const [data, error] = response;
                if (!data && error) {
                    host.setError(error);
                }
            },
            groupEventCreateTriggered: async (event, nylasSchedulerConfigConnector) => {
                const { groupEvent, configId, host } = event.detail;
                const response = await nylasSchedulerConfigConnector.schedulerConfig.createGroupEvent(groupEvent, configId);
                const [data, error] = response;
                if (!data && error) {
                    host.setError(error);
                }
            },
            groupEventImportTriggered: async (event, nylasSchedulerConfigConnector) => {
                const { groupEvent, configId, host } = event.detail;
                const response = await nylasSchedulerConfigConnector.schedulerConfig.importGroupEvent([groupEvent], configId);
                const [data, error] = response;
                if (!data && error) {
                    host.setError(error);
                }
                if (data && data.import_failed && data.import_failed.length > 0) {
                    const errorMessage = data.import_failed.map(failedEvent => failedEvent.reason).join('\n');
                    host.setError(new Error(errorMessage));
                    setTimeout(() => {
                        host.resetError();
                    }, 5000);
                }
            },
            saveGroupEventChangesError: async (event, _nylasSchedulerConfigConnector) => {
                const { error, host } = event.detail;
                debug('[nylas-editor-tabs-group]', 'saveGroupEventChangesError', error, host);
            },
        },
        localPropsToProp: new Map([
            ['schedulerPreviewLink', 'schedulerPreviewLink'],
            ['enableUserFeedback', 'enableUserFeedback'],
            ['hideEditorTabs', 'hideEditorTabs'],
        ]),
        fireRegisterEvent: true,
    }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], NylasEditorTabsGroup.prototype, "render", null);
//# sourceMappingURL=nylas-editor-tabs-group.js.map
